summaryrefslogtreecommitdiffstats
path: root/juk/collectionlist.h
diff options
context:
space:
mode:
Diffstat (limited to 'juk/collectionlist.h')
-rw-r--r--juk/collectionlist.h56
1 files changed, 28 insertions, 28 deletions
diff --git a/juk/collectionlist.h b/juk/collectionlist.h
index c5cafca2..4143889c 100644
--- a/juk/collectionlist.h
+++ b/juk/collectionlist.h
@@ -20,9 +20,9 @@
#include <kdirwatch.h>
#include <kfileitem.h>
-#include <qdict.h>
-#include <qclipboard.h>
-#include <qvaluevector.h>
+#include <tqdict.h>
+#include <tqclipboard.h>
+#include <tqvaluevector.h>
#include "playlist.h"
#include "playlistitem.h"
@@ -32,21 +32,21 @@ class CollectionListItem;
class ViewMode;
/**
* This type is for mapping QString track attributes like the album, artist
* and track to an integer count representing the number of outstanding items
* that hold the string.
*/
-typedef QDict<int> TagCountDict;
-typedef QDictIterator<int> TagCountDictIterator;
+typedef TQDict<int> TagCountDict;
+typedef TQDictIterator<int> TagCountDictIterator;
/**
* We then have an array of dicts, one for each column in the list view. We
* use pointers to TagCountDicts because QDict has a broken copy ctor, which
* doesn't copy the case sensitivity setting.
*/
-typedef QValueVector<TagCountDict*> TagCountDicts;
+typedef TQValueVector<TagCountDict*> TagCountDicts;
/**
* This is the "collection", or all of the music files that have been opened
@@ -78,12 +78,12 @@ public:
/**
* Returns a unique set of values associated with the type specified.
*/
- QStringList uniqueSet(UniqueSetType t) const;
+ TQStringList uniqueSet(UniqueSetType t) const;
- CollectionListItem *lookup(const QString &file) { return m_itemsDict.find(file); }
+ CollectionListItem *lookup(const TQString &file) { return m_itemsDict.find(file); }
virtual PlaylistItem *createItem(const FileHandle &file,
- QListViewItem * = 0,
+ TQListViewItem * = 0,
bool = false);
void emitVisibleColumnsChanged() { emit signalVisibleColumnsChanged(); }
@@ -99,8 +99,8 @@ public slots:
virtual void clear();
void slotCheckCache();
- void slotRemoveItem(const QString &file);
- void slotRefreshItem(const QString &file);
+ void slotRemoveItem(const TQString &file);
+ void slotRefreshItem(const TQString &file);
void slotNewItems(const KFileItemList &items);
void slotRefreshItems(const KFileItemList &items);
@@ -110,24 +110,24 @@ protected:
CollectionList(PlaylistCollection *collection);
virtual ~CollectionList();
- virtual void contentsDropEvent(QDropEvent *e);
- virtual void contentsDragMoveEvent(QDragMoveEvent *e);
+ virtual void contentsDropEvent(TQDropEvent *e);
+ virtual void contentsDragMoveEvent(TQDragMoveEvent *e);
// These methods are used by CollectionListItem, which is a friend class.
- void addToDict(const QString &file, CollectionListItem *item) { m_itemsDict.replace(file, item); }
- void removeFromDict(const QString &file) { m_itemsDict.remove(file); }
+ void addToDict(const TQString &file, CollectionListItem *item) { m_itemsDict.replace(file, item); }
+ void removeFromDict(const TQString &file) { m_itemsDict.remove(file); }
// These methods are also used by CollectionListItem, to manage the
// strings used in generating the unique sets and tree view mode playlists.
- QString addStringToDict(const QString &value, unsigned column);
- void removeStringFromDict(const QString &value, unsigned column);
+ TQString addStringToDict(const TQString &value, unsigned column);
+ void removeStringFromDict(const TQString &value, unsigned column);
- void addWatched(const QString &file) { m_dirWatch->addFile(file); }
- void removeWatched(const QString &file) { m_dirWatch->removeFile(file); }
+ void addWatched(const TQString &file) { m_dirWatch->addFile(file); }
+ void removeWatched(const TQString &file) { m_dirWatch->removeFile(file); }
- virtual bool hasItem(const QString &file) const { return m_itemsDict.find(file); }
+ virtual bool hasItem(const TQString &file) const { return m_itemsDict.find(file); }
signals:
void signalCollectionChanged();
@@ -140,8 +140,8 @@ signals:
* \see Playlsit::isColumnVisible()
*/
void signalVisibleColumnsChanged();
- void signalNewTag(const QString &, unsigned);
- void signalRemovedTag(const QString &, unsigned);
+ void signalNewTag(const TQString &, unsigned);
+ void signalRemovedTag(const TQString &, unsigned);
private:
/**
@@ -151,7 +151,7 @@ private:
static const int m_uniqueSetCount = 3;
static CollectionList *m_list;
- QDict<CollectionListItem> m_itemsDict;
+ TQDict<CollectionListItem> m_itemsDict;
KDirWatch *m_dirWatch;
TagCountDicts m_columnTags;
};
@@ -163,14 +163,14 @@ class CollectionListItem : public PlaylistItem
friend class PlaylistItem;
/**
* Needs access to the destructor, even though the destructor isn't used by QDict.
*/
- friend class QDict<CollectionListItem>;
+ friend class TQDict<CollectionListItem>;
public:
virtual void refresh();
PlaylistItem *itemForPlaylist(const Playlist *playlist);
- void updateCollectionDict(const QString &oldPath, const QString &newPath);
+ void updateCollectionDict(const TQString &oldPath, const TQString &newPath);
void repaint() const;
PlaylistItemList children() const { return m_children; }
@@ -32,21 +32,21 @@ class CollectionListItem;
class ViewMode;
/**
- * This type is for mapping QString track attributes like the album, artist
+ * This type is for mapping TQString track attributes like the album, artist
* and track to an integer count representing the number of outstanding items
* that hold the string.
@@ -32,21 +32,21 @@ class CollectionListItem;
/**
* We then have an array of dicts, one for each column in the list view. We
- * use pointers to TagCountDicts because QDict has a broken copy ctor, which
+ * use pointers to TagCountDicts because TQDict has a broken copy ctor, which
* doesn't copy the case sensitivity setting.
*/
@@ -163,14 +163,14 @@ class CollectionListItem : public PlaylistItem
friend class PlaylistItem;
/**
- * Needs access to the destructor, even though the destructor isn't used by QDict.
+ * Needs access to the destructor, even though the destructor isn't used by TQDict.
*/